@@ -1,6 +1,8 @@
+
 import argparse
 import sys
 import traceback
+from typing import List
 
 HELP_MSG = '''
 surfing <command> [<args>]
@@ -16,6 +18,7 @@ The most commonly used commands are:
     update_view             update view data based on basic and derived data
     data_update             run download_raw, update_basic, update_derived and update_view in turn
     check_fund_list         check fund list to get new funds and delisted funds
+    dump_tables_and_dfs     dump all tables and dfs of fund dm to s3
 '''
 
 
@@ -167,6 +170,7 @@ class SurfingEntrance(object):
         wechat_bot.send_data_update_status(yesterday, failed_tasks, updated_count)
 
         self.check_fund_list(yesterday, wechat_bot)
+        self.dump_tables_and_dfs(yesterday, wechat_bot)
 
     def calc_fund_estimated_nav(self):
         # Use Jenkins to call this function every hour
@@ -362,6 +366,37 @@ class SurfingEntrance(object):
                             new_delisted_funds_with_name[fund_id] += '(场内)'
         wechat_bot.send_new_fund_list(yesterday, new_funds_with_name, new_delisted_funds_with_name)
 
+    def dump_tables_and_dfs(self, yesterday=None, wechat_bot=None):
+        from .data.manager.etl_tool import SynchronizerS3ForDM
+        from .data.manager.manager_fund import FundDataManager
+
+        print('to dump tables and dfs to s3')
+        # 构建一个默认的DM
+        try:
+            fdm = FundDataManager()
+            fdm.init(score_pre_calc=True, print_time=True, use_weekly_monthly_indicators=False)
+        except Exception as e:
+            print(f'init dm failed (err_msg){e}')
+
+        if fdm.inited:
+            # 默认DM初始化成功，用它的数据向S3同步所有df
+            syncer = SynchronizerS3ForDM(dm=fdm)
+            failed_dfs: List[str] = syncer.dump_all_dfs()
+        else:
+            print('init dm failed, dump tables only')
+            syncer = SynchronizerS3ForDM()
+            failed_dfs: ['init dm']
+        # 向S3同步所有table
+        failed_tables: List[str] = syncer.dump_all_tables()
+
+        # 发送同步结果
+        if yesterday is None:
+            yesterday = self._get_yesterday()
+        if wechat_bot is None:
+            from .util.wechat_bot import WechatBot
+            wechat_bot = WechatBot()
+        wechat_bot.send_dump_to_s3_result(yesterday, failed_tables, failed_dfs)
+
 
 if __name__ == "__main__":
     entrance = SurfingEntrance()
