@@ -1,11 +1,13 @@
 from typing import List, Tuple, Union
 import pandas as pd
-from ..wrapper.mysql import RawDatabaseConnector
-from ..view.raw_models import *
 from sqlalchemy.sql import func
 
+from ...util.singleton import Singleton
+from ..wrapper.mysql import RawDatabaseConnector
+from ..view.raw_models import *
 
-class RawDataApi:
+
+class RawDataApi(metaclass=Singleton):
     def get_raw_cm_index_price_df(self, start_date, end_date):
         with RawDatabaseConnector().managed_session() as db_session:
             try:
@@ -629,16 +631,21 @@ class RawDataApi:
                 print(f'Failed to get data <err_msg> {e} from {CSIndexComponent.__tablename__}')
                 return None
 
-    def get_em_fund_holding_rate(self, start_date: str):
+    def get_em_fund_holding_rate(self, start_date: str = '', end_date: str = ''):
         with RawDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
                     EmFundHoldingRate
-                ).filter(
-                    EmFundHoldingRate.DATES >= start_date,
                 )
-                df = pd.read_sql(query.statement, query.session.bind)
-                return df
+                if start_date:
+                    query = query.filter(
+                        EmFundHoldingRate.DATES >= start_date,
+                    )
+                if end_date:
+                    query = query.filter(
+                        EmFundHoldingRate.DATES <= end_date,
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print('Failed to get data <err_msg> {}'.format(e))
                 return None
@@ -818,16 +825,17 @@ class RawDataApi:
                 print(f'Failed to get data <err_msg> {e} from {WindIndPortfolio.__tablename__}')
                 return None
 
-    def get_em_fund_rate(self, datetime: str):
+    def get_em_fund_rate(self, datetime: str = ''):
         with RawDatabaseConnector().managed_session() as raw_session:
             try:
                 query = raw_session.query(
                     EMFundRate
-                ).filter(
-                    EMFundRate.DATES == datetime,
                 )
-                df = pd.read_sql(query.statement, query.session.bind)
-                return df
+                if datetime:
+                    query = query.filter(
+                        EMFundRate.DATES == datetime,
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {EMFundRate.__tablename__}')
                 return None
@@ -989,3 +997,43 @@ class RawDataApi:
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {EmBondRating.__tablename__}')
+
+    def get_em_macroeconomic_monthly(self, codes: Tuple[str] = (), start_date: str = '', end_date: str = ''):
+        with RawDatabaseConnector().managed_session() as raw_session:
+            try:
+                query = raw_session.query(EmMacroEconomicMonthly)
+                if codes:
+                    query = query.filter(
+                        EmMacroEconomicMonthly.codes.in_(codes),
+                    )
+                if start_date:
+                    query = query.filter(
+                        EmMacroEconomicMonthly.datetime >= start_date,
+                    )
+                if end_date:
+                    query = query.filter(
+                        EmMacroEconomicMonthly.datetime <= end_date,
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {EmMacroEconomicMonthly.__tablename__}')
+
+    def get_em_macroeconomic_daily(self, codes: Tuple[str] = (), start_date: str = '', end_date: str = ''):
+        with RawDatabaseConnector().managed_session() as raw_session:
+            try:
+                query = raw_session.query(EmMacroEconomicDaily)
+                if codes:
+                    query = query.filter(
+                        EmMacroEconomicDaily.codes.in_(codes),
+                    )
+                if start_date:
+                    query = query.filter(
+                        EmMacroEconomicDaily.datetime >= start_date,
+                    )
+                if end_date:
+                    query = query.filter(
+                        EmMacroEconomicDaily.datetime <= end_date,
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {EmMacroEconomicDaily.__tablename__}')
