@@ -113,6 +113,8 @@ class BasicDataPart1:
                 return '短期纯债型基金'
             elif invest_type_class == '混合债券型基金（二级）':
                 return '混合债券型二级基金'
+            elif invest_type_class == '被动指数型基金':
+                return '被动指数型债券基金'
             elif invest_type_class in ('QDII基金', '封闭式基金', '保本型基金'):
                 # error case
                 return
@@ -191,12 +193,18 @@ class BasicDataPart1:
             fee = em_fund_fee.loc[x, ['manage_fee', 'trustee_fee', 'purchase_fee', 'redeem_fee']]
             return fee.transform(_parse_fee)
 
-        # 只处理非场内基金
-        fund_id_list = [one for one in fund_id_list if '.OF' in one]
         # 获取raw中的基金基础信息
         df = self._raw_data_api.get_em_fund_info(fund_id_list).drop(columns='_update_time')
         # 其中一部分列可以直接使用，改一下名字即可
         df = df.rename(columns={'em_id': 'wind_id', 'name': 'desc_name', 'manager_id': 'pre_fund_manager'})
+        # is open
+        df['is_open'] = 1
+        key_words = ['封闭','定期','定开']
+        key_words = '|'.join(key_words)
+        _wind_ids = df[df['desc_name'].str.contains(key_words)].wind_id
+        df = df.set_index('wind_id')
+        df.loc[_wind_ids,'is_open'] = 0
+        df = df.reset_index()
         # 没有end_date的话给一个默认值
         df['end_date'] = df['end_date'].where(df.end_date.notna(), '2040-12-31')
         # 这里可能还需要加上港币
@@ -222,6 +230,8 @@ class BasicDataPart1:
         # 拆解上边的benchmark
         df[['benchmark_1', 'benchmark_2']] = df.benchmark.apply(_lambda_benchmark)
         df = df.drop(columns='invest_type_class_2').reset_index()
+        # 将场内变为场外的
+        df['wind_id'] = df.wind_id.transform(lambda x: x.split('.')[0] + '.OF' if '.OF' not in x else x)
         self._data_helper._upload_basic(df, FundInfo.__table__.name)
 
     def index_info(self):
@@ -239,7 +249,6 @@ class BasicDataPart1:
         # 先全体置为false，后续可以手工修改
         df['is_select'] = False
         df['tag_method'] = 'PE百分位'
-        df['price_source'] = df['price_source'].transform(lambda x: x.name)
         # index_id是人工起的，所以只能作为参数传进来
         df['index_id'] = index_ids
         self._data_helper._upload_basic(df, IndexInfo.__table__.name)
@@ -274,7 +283,6 @@ class BasicDataPart1:
         df = self._raw_data_api.get_cs_index_component().drop(columns=['_update_time'])
         df['index_id'] = df['index_id'].map(em_id_to_index_id)
         df['sector'] = df['sector'].transform(lambda x: _lambda_func_index_component_2(em_id_to_index_id, x))
-        df['id_cat'] = df['id_cat'].transform(lambda x: x.name)
         fund_info_df = self._fund_info_df.set_index('wind_id')
         wind_id_to_id: Dict[str, str] = fund_info_df['fund_id'].to_dict()
         df['related_funds'] = df['related_funds'].transform(lambda x: _lambda_func_index_component_3(wind_id_to_id, x))
@@ -344,7 +352,7 @@ class BasicDataPart1:
             raw_start_date_dt: datetime.date = pd.to_datetime(start_date, infer_datetime_format=True).date()
             # 多取N个交易日的数据
             start_date = raw_start_date_dt - datetime.timedelta(days=90)
-            trading_day_df = BasicDataApi().get_trading_day_list(start_date.start_date.strftime('%Y%m%d'), end_date)
+            trading_day_df = BasicDataApi().get_trading_day_list(start_date.strftime('%Y%m%d'), end_date)
             trading_day_df = trading_day_df[trading_day_df.datetime <= raw_start_date_dt]
             assert trading_day_df.datetime.size >= INDEX_PRICE_EXTRA_TRADE_DAYS, f'should at least have {INDEX_PRICE_EXTRA_TRADE_DAYS} trading days'
             # del_date在start_date后边一天，确保可以正确计算ret等daily difference
@@ -558,8 +566,8 @@ class BasicDataPart1:
             if df is None:
                 print('failed to get em fund scale for fund size')
                 return False
-            # 过滤掉非.OF的基金
-            df = df[df.CODES.str.contains('.OF')]
+            # 将场内变为场外的
+            df['CODES'] = df.CODES.transform(lambda x: x.split('.')[0] + '.OF' if '.OF' not in x else x)
             df = df.pivot_table(index='DATES', columns='CODES', values='FUNDSCALE').fillna(method='ffill')
             df = df.iloc[[-1], :].apply(lambda x: pd.Series({'fund_id': self._data_helper._get_fund_id_from_order_book_id(x.name.split('.')[0], x.index.array[0]), 'latest_size': float(x.array[0])})).T
             df = df.reset_index(drop=True)
@@ -577,9 +585,9 @@ class BasicDataPart1:
             if df is None:
                 print('failed to get em fund scale for fund status latest')
                 return False
-            # 过滤掉非.OF的基金
-            df = df[df.CODES.str.contains('.OF')]
-            df = df.pivot(index='DATES', columns='CODES', values=['PURCHSTATUS', 'REDEMSTATUS', 'LPLIMIT', 'OTCLPLIMIT', 'TRADESTATUS']).fillna(method='ffill')
+            # 将场内变为场外的
+            df['CODES'] = df.CODES.transform(lambda x: x.split('.')[0] + '.OF' if '.OF' not in x else x)
+            df = df.pivot(index='DATES', columns='CODES', values=['PURCHSTATUS', 'REDEMSTATUS', 'LPLIMIT', 'OTCLPLIMITJG', 'OTCLPLIMITGR', 'TRADESTATUS']).fillna(method='ffill')
             df = df.iloc[[-1], :].stack().reset_index()
             df['fund_id'] = df[['DATES', 'CODES']].apply(lambda x: self._data_helper._get_fund_id_from_order_book_id(x.CODES.split('.')[0], x.DATES), axis=1)
             df = df[df.fund_id.notna()]
@@ -696,45 +704,35 @@ class BasicDataPart1:
             return False
 
     def fund_size_hold_rate_history(self):
-        start_date = '20200630'
-        end_date = '20200821'
+        start_date = '20040331'
+        end_date = '20100331'
         raw = self._raw_data_api
-        fund_holding_rate = raw.get_em_fund_holding_rate(start_date=start_date)
+
+        fund_holding_rate = raw.get_em_fund_holding_rate(start_date=start_date, end_date=end_date)
         fund_holding_rate['fund_id'] = fund_holding_rate.apply(
             lambda x: self._data_helper._get_fund_id_from_order_book_id(x['CODES'].split('.')[0], x['DATES']), axis=1)
         fund_holding_rate = fund_holding_rate.drop(['CODES', '_update_time'], axis=1).rename(columns={
-            'DATES':'datetime',
-            'HOLDPERSONALHOLDINGPCT':'personal_holds',
-            'HOLDINSTIHOLDINGPCT':'institution_holds',
+            'DATES': 'datetime',
+            'HOLDPERSONALHOLDINGPCT': 'personal_holds',
+            'HOLDINSTIHOLDINGPCT': 'institution_holds',
             'HOLDNUM': 'hold_num',
         })
         fund_holding_rate = fund_holding_rate[fund_holding_rate.drop(columns='fund_id').notna().any(axis=1)]
+
         fund_scale = raw.get_em_fund_scale(start_date=start_date, end_date=end_date)
-        fund_scale = fund_scale.pivot(index='DATES', columns='CODES', values='FUNDSCALE').fillna(method='ffill').iloc[[-1], :].stack()
+        fund_scale = fund_scale.pivot(index='DATES', columns='CODES', values='FUNDSCALE').fillna(method='ffill').stack()
         fund_scale = pd.DataFrame(fund_scale, columns=['FUNDSCALE']).reset_index()
         fund_scale['fund_id'] = fund_scale.apply(
             lambda x: self._data_helper._get_fund_id_from_order_book_id(x['CODES'].split('.')[0], x['DATES']), axis=1)
         fund_scale = fund_scale.drop(['CODES'], axis=1).rename(columns={'DATES': 'datetime', 'FUNDSCALE': 'size'})
         fund_scale = fund_scale.dropna().drop_duplicates(subset=['size', 'fund_id'], keep='first')
-        fund_scale['datetime'] = pd.to_datetime(start_date).date()
-        fund_list = list(set(fund_scale.fund_id))
-        res = []
-        for fund_id in fund_list:
-            fund_hold_i = fund_holding_rate[fund_holding_rate.fund_id == fund_id].drop(columns='fund_id').set_index('datetime')
-            fund_scale_i = fund_scale[fund_scale.fund_id == fund_id].drop(columns='fund_id').set_index('datetime')
-            _df = fund_scale_i.join(fund_hold_i).fillna(method='ffill').reset_index()
-            _df['fund_id'] = fund_id
-            res.append(_df)
-        df = pd.concat(res)
-        df = df.drop_duplicates(subset=['datetime','fund_id'],keep='first')
-        # con_list = (df.personal_holds + df.institution_holds) == 100
-        # df = df[con_list]
+
+        df = fund_scale.set_index(['fund_id', 'datetime']).join(fund_holding_rate.set_index(['fund_id', 'datetime']), how='outer').reset_index()
         self._data_helper._upload_basic(df, Fund_size_and_hold_rate.__table__.name)
 
     def fund_hold_asset(self, start_date: str, end_date: str):
         # history, update only on report date
         em_hold_asset = self._raw_data_api.get_em_fund_hold_asset(start_date, end_date)
-        em_hold_asset = em_hold_asset[em_hold_asset.CODES.str.contains('.OF')]
         em_hold_asset['CODES'] = em_hold_asset.apply(lambda x:
                             self._data_helper._get_fund_id_from_order_book_id(x.CODES.split('.')[0], x.DATES), axis=1)
         em_hold_asset = em_hold_asset.dropna(subset=['CODES']).drop(columns='_update_time')
@@ -754,7 +752,6 @@ class BasicDataPart1:
     def fund_hold_industry(self, end_date: str):
         # history, update only on report date
         em_hold_industry = self._raw_data_api.get_em_fund_hold_industry(end_date)
-        em_hold_industry = em_hold_industry[em_hold_industry.CODES.str.contains('.OF')]
         em_hold_industry['CODES'] = em_hold_industry.apply(lambda x:
                             self._data_helper._get_fund_id_from_order_book_id(x.CODES.split('.')[0], x.DATES), axis=1)
         em_hold_industry = em_hold_industry.dropna(subset=['CODES']).drop(columns='_update_time')
@@ -877,3 +874,4 @@ if __name__ == '__main__':
     # bdp.sector_funds()
     # bdp.index_component()
     # bdp.fund_rate('20200812')
+    # bdp.fund_size_hold_rate_history()
