@@ -4,7 +4,6 @@ from typing import List
 
 import pandas as pd
 
-from .fund_score_processor import FundScoreProcessor
 from .fund_indicator_processor import FundIndicatorProcessor
 # from .derived_index_val import IndexValProcess
 from .derived_index_val_long_term import IndexValProcessLongTerm
@@ -15,10 +14,14 @@ from .fund_indicator_processor_monthly import FundIndicatorProcessorMonthly
 from .derived_indicators_processor_group import FundIndicatorProcessorGroup
 from .derived_index_ret_vol import IndexIndicatorProcessor
 from .derived_fund_aic import AIPProcess
+from .derived_mng_fund_rank import FundManagerFundRankProcessor
 # from .derived_fund_score_extended import FundScoreExtendedProcess
 from .derived_fund_score_group import FundScoreGroupProcess
+from .derived_fund_score_group_v1 import FundScoreGroupV1Process
 from .barra_cne5_factor_processor import BarraCNE5FactorProcessor
 from .style_reg_processer import StyleBoxReg
+from .style_box import StyleBoxGenerator
+from .fund_manager_processor import ManagerProcessor
 from ...api.basic import BasicDataApi
 
 
@@ -29,17 +32,20 @@ class DerivedDataProcessor:
         self.fund_indicator_processor_weekly = FundIndicatorProcessorWeekly(self._data_helper)
         self.fund_indicator_processor_monthly = FundIndicatorProcessorMonthly(self._data_helper)
         self.fund_indicator_processor_group = FundIndicatorProcessorGroup(self._data_helper)
-        self.fund_score_processor = FundScoreProcessor(self._data_helper)
+        self._manager_processor = ManagerProcessor(self._data_helper)
         # self.index_val_processor = IndexValProcess(self._data_helper)
         self.index_val_processor_long_term = IndexValProcessLongTerm(self._data_helper)
         self.index_indicator = IndexIndicatorProcessor(self._data_helper)
         self.fund_aip = AIPProcess(self._data_helper)
         # 这版基金评分先不用了，这里先注释掉
         # self._derived_fund_score_extended = FundScoreExtendedProcess(self._data_helper)
+        self._derived_fund_score_group_v1 = FundScoreGroupV1Process(self._data_helper)
         self._derived_fund_score_group = FundScoreGroupProcess(self._data_helper)
         self._barra_cne5_factor_processor = BarraCNE5FactorProcessor(self._data_helper)
         self._style_regression_processor = StyleBoxReg(self._data_helper)
+        self._style_box_processor = StyleBoxGenerator(self._data_helper)
         self.style_analysis_processors: List[StyleAnalysisProcessor] = []
+        self.mng_fund_rank = FundManagerFundRankProcessor(self._data_helper)
         # 暂时只算这三个universe
         for universe in ('hs300', 'csi800', 'all'):
             sap = StyleAnalysisProcessor(self._data_helper, universe)
@@ -48,13 +54,15 @@ class DerivedDataProcessor:
     def process_all(self, start_date, end_date):
         failed_tasks = []
         failed_tasks.extend(self.fund_indicator_processor.process(start_date, end_date))
-        failed_tasks.extend(self.fund_score_processor.process(start_date, end_date))
         # failed_tasks.extend(self.index_val_processor.process(start_date, end_date))
         failed_tasks.extend(self.index_val_processor_long_term.process(start_date, end_date))
         failed_tasks.extend(self.index_indicator.process(end_date))
+        failed_tasks.extend(self._manager_processor.process(end_date))
         failed_tasks.extend(self.fund_aip.process(start_date, end_date))
         failed_tasks.extend(self._barra_cne5_factor_processor.process(start_date, end_date))
         failed_tasks.extend(self._style_regression_processor.process(start_date, end_date))
+        failed_tasks.extend(self._style_box_processor.process(start_date, end_date))
+        failed_tasks.extend(self.mng_fund_rank.process(end_date))
         for sap in self.style_analysis_processors:
             failed_tasks.extend(sap.process(start_date, end_date))
 
@@ -76,6 +84,7 @@ class DerivedDataProcessor:
                 failed_tasks.extend(self.fund_indicator_processor_weekly.process(start_date, end_date, end_date_dt))
                 failed_tasks.extend(self.fund_indicator_processor_group.process(start_date, end_date, end_date_dt))
                 # failed_tasks.extend(self._derived_fund_score_extended.process(start_date, end_date, end_date_dt))
+                failed_tasks.extend(self._derived_fund_score_group_v1.process(start_date, end_date, end_date_dt))
                 failed_tasks.extend(self._derived_fund_score_group.process(start_date, end_date, end_date_dt))
 
             if end_date_dt.year == next_trading_dt.year and end_date_dt.month == next_trading_dt.month:
