@@ -5,8 +5,9 @@ from sqlalchemy import func
 from ...wrapper.mysql import (RawDatabaseConnector, BasicDatabaseConnector, DerivedDatabaseConnector, 
     ViewDatabaseConnector)
 from ...view.view_models import FundDailyCollection
-from ...view.basic_models import FundNav, FundInfo, FundRate, FundSize, FundRet, FundBenchmark, IndexInfo, FundStatusLatest
-from ...view.derived_models import FundAlpha, FundScore, FundIndicator
+from ...view.basic_models import FundNav, FundInfo, FundRate, FundSize, FundRet, FundBenchmark, IndexInfo, \
+    FundStatusLatest
+from ...view.derived_models import FundAlpha, FundScore, FundIndicator, FundScoreNew
 from ....constant import ExchangeStatus
 
 class FundDailyCollectionProcessor(object):
@@ -197,7 +198,8 @@ class FundDailyCollectionProcessor(object):
                     FundStatusLatest.PURCHSTATUS,
                     FundStatusLatest.REDEMSTATUS,
                     FundStatusLatest.LPLIMIT,
-                    FundStatusLatest.OTCLPLIMIT,
+                    FundStatusLatest.OTCLPLIMITJG,
+                    FundStatusLatest.OTCLPLIMITGR,
                 )
                 df = pd.read_sql(query.statement, query.session.bind)
                 print(df)
@@ -249,6 +251,35 @@ class FundDailyCollectionProcessor(object):
             except Exception as e:
                 print('Failed get_score_df <err_msg> {}'.format(e))
 
+    def get_score_new_df(self):
+        with DerivedDatabaseConnector().managed_session() as mn_session:
+            try:
+                subq = mn_session.query(
+                    FundScoreNew.fund_id.label('temp_id'),
+                    func.max(FundScoreNew.datetime).label('temp_date'),
+                ).group_by(FundScoreNew.fund_id).subquery()
+
+                query = mn_session.query(
+                    FundScoreNew.fund_id,
+                    FundScoreNew.return_score,
+                    FundScoreNew.robust_score,
+                    FundScoreNew.risk_score,
+                    FundScoreNew.timing_score,
+                    FundScoreNew.selection_score,
+                    FundScoreNew.team_score,
+                    FundScoreNew.total_score,
+                ).filter(
+                    FundScoreNew.fund_id == subq.c.temp_id,
+                    FundScoreNew.datetime == subq.c.temp_date
+                )
+
+                df = pd.read_sql(query.statement, query.session.bind)
+                df = df.drop_duplicates(subset=['fund_id'], keep='last')
+                return df
+
+            except Exception as e:
+                print('Failed get_score_new_df <err_msg> {}'.format(traceback.format_exc()))
+
     def get_tag_fund_indicator_df(self):
         with DerivedDatabaseConnector().managed_session() as mn_session:
             try:
@@ -369,6 +400,9 @@ class FundDailyCollectionProcessor(object):
             score = self.get_score_df().set_index('fund_id')
             print(score)
             print('-' * 100)
+            new_score = self.get_score_new_df().set_index('fund_id')
+            print(new_score)
+            print('-' * 100)
             tag_indicator = self.get_tag_fund_indicator_df().set_index('fund_id')
             print(tag_indicator)
             print('-' * 100)
@@ -385,7 +419,7 @@ class FundDailyCollectionProcessor(object):
             print('-' * 100)
 
             print('处理净值')
-            df = pd.concat([funds, bench, nav, alpha, size, rating, score, tag_indicator, exchange_status], axis=1, sort=False)
+            df = pd.concat([funds, bench, nav, alpha, size, rating, score, new_score, tag_indicator, exchange_status], axis=1, sort=False)
             df.index.name = 'fund_id'
             print('_'*100)
             print(df)
@@ -431,7 +465,6 @@ class FundDailyCollectionProcessor(object):
             df = df.drop_duplicates(subset=['order_book_id'], keep='first')
             df = df.dropna(subset=['order_book_id'])
 
-
             # df.to_csv('./hhh.csv')
             self.append_data(FundDailyCollection.__tablename__, df)
 
