@@ -15,6 +15,7 @@ class AssetDict:
     cash: float=0.0
     mmf: float=0.0
     hsi: float=0.0
+    active: float=0.0
     def __repr__(self):
         s = f'<{self.__class__.__name__}'
         for k, v in self.__dict__.items():
@@ -39,6 +40,7 @@ class AssetTimeSpan:
     gold: int=1
     mmf: int=1
     hsi: int=1
+    active: int=1
 
 @dataclasses.dataclass
 class AssetWeight(AssetDict):
@@ -261,6 +263,7 @@ class TAAParam:
     TuneCash:     bool=False    # 默认taa调仓时，不调整cash
     ToMmf:        bool=True    # 默认taa加减仓不改变货基权重
 
+# dataclass默认有__eq__
 @dataclasses.dataclass
 class FundScoreParam:
     tag_type: int=1
@@ -529,6 +532,7 @@ class TaaTunerParam:
         'sp500rmb':'pe_ttm',
     }
 
+# dataclass默认有__eq__
 @dataclasses.dataclass
 class ScoreFilter:
 
@@ -538,8 +542,9 @@ class ScoreFilter:
     SizeTop:int = 1e10
     
     def __post_init__(self):
-        self.FilterIndexId = self.FilterIndexId or ['national_debt']
+        self.FilterIndexId = self.FilterIndexId or ['national_debt','active']
 
+# dataclass默认有__eq__
 @dataclasses.dataclass
 class ScorePenaltyParams:
 
@@ -551,6 +556,28 @@ class ScorePenaltyParams:
     def __post_init__(self):
         self.FilterYearIndex = self.FilterYearIndex or ['national_debt', 'csi500', 'gem', 'hs300', 'sp500rmb', 'gold']
 
+@dataclasses.dataclass
+class ScoreType:
+
+    Passive:str = 'passive'
+    Enhanced:str = 'enhanced'
+    Active:str = 'active'
+    Temp:str = 'temp'
+    Default:str = 'default'
+
+@dataclasses.dataclass
+class ScoreSelect:
+
+    hs300:str           =   ScoreType.Enhanced
+    csi500:str          =   ScoreType.Enhanced
+    gem:str             =   ScoreType.Enhanced
+    national_debt:str   =   ScoreType.Default
+    mmf:str             =   ScoreType.Default
+    sp500rmb:str        =   ScoreType.Default
+    gold:str            =   ScoreType.Default
+    hsi:str             =   ScoreType.Default
+    active:str          =   ScoreType.Default
+
 if __name__ == '__main__':
     a = AssetWeight(hs300=0.1, csi500=0.1, cash=0.8)
     print(a)
\ No newline at end of file
