@@ -31,7 +31,7 @@ class FundPainter(object):
             res.append(v)
         weights_df = pd.DataFrame(res).set_index('date')
         weights_df = weights_df.div(weights_df.sum(axis=1), axis=0)
-        weights_df.fillna(0)[1:].plot.area(figsize=(18,9),legend=False,fontsize = 17)
+        weights_df.fillna(0)[1:].round(3).plot.area(figsize=(18,9),legend=False,fontsize = 17)
         s = pl.title('fund weights history', fontsize=20)
         st = [k+':'+str(round(v,2)) for k, v in saa.items() if v > 0]
         st = ' '.join(st)
@@ -185,6 +185,7 @@ class FundPainter(object):
                         fund_indicator:pd.DataFrame,
                         asset=str,
                         is_tuning=bool,
+                        score_select=dict,
                         ):
         fund_w = fund_weights_history
         end_date = fund_mv.index.tolist()[-1]
@@ -238,9 +239,9 @@ class FundPainter(object):
                 dic = {
                     'fund_id' : f,
                     'desc_name' : desc,
-                    'score' : round(fund_score[submit_d][asset][f],4),
+                    'score' : round(fund_score[submit_d][asset][score_select[asset]][f],4),
                     'weight': round(fund_w[b_d][f], 4),
-                    'score_raw': round(fund_score_raw[submit_d][asset][f],4),
+                    'score_raw': round(fund_score_raw[submit_d][asset][score_select[asset]][f],4),
                 }
                 for s in ['alpha','beta','fee_rate','track_err']:
                     dic[s] = round(f_i_dict[s],4)
@@ -248,7 +249,7 @@ class FundPainter(object):
                 plt.plot(fund_tmp.index, fund_tmp[f], label=f+'_'+desc,linestyle='--',linewidth=3.0)    
             
             if is_tuning:
-                fund_not_select = [f for f, v in fund_score[submit_d][asset].items() if f not in f_l][:10]
+                fund_not_select = [f for f, v in fund_score[submit_d][asset][score_select[asset]].items() if f not in f_l][:10]
                 if len(fund_not_select) < 1:
                     plt.legend(fontsize=17, loc = 'lower left')
                     plt.title(f'{asset} {b_d} {e_d}', fontsize=25)
@@ -264,9 +265,9 @@ class FundPainter(object):
                     dic = {
                         'fund_id' : f,
                         'desc_name' : desc,
-                        'score' : round(fund_score[submit_d][asset][f],4),
+                        'score' : round(fund_score[submit_d][asset][score_select[asset]][f],4),
                         'weight': 0,
-                        'score_raw': round(fund_score_raw[submit_d][asset][f],4),
+                        'score_raw': round(fund_score_raw[submit_d][asset][score_select[asset]][f],4),
                     }
                     for s in ['alpha','beta','fee_rate','track_err']:
                         dic[s] = round(f_i_dict[s],4)
@@ -275,7 +276,9 @@ class FundPainter(object):
 
             plt.legend(fontsize=17, loc = 'lower left')
             plt.title(f'{asset} {b_d} {e_d}', fontsize=25)
-            plt.suptitle(FundScoreManager().funcs[asset].__dict__, y=0.87, fontsize=18)
+            _score = FundScoreManager().funcs[asset][score_select[asset]].__dict__
+            _score = {fac:w for fac, w in _score.items() if w != 0}
+            plt.suptitle(_score, y=0.87, fontsize=18)
             ax.xaxis.set_ticks_position('top')
             fund_df = pd.DataFrame(res)
             fund_df = fund_df[['desc_name','fund_id','weight','alpha','beta','track_err','fee_rate','score_raw','score']]
@@ -420,13 +423,15 @@ class FundPainter(object):
                     index_df_i[fund_id] = index_df_i[fund_id] * fee_discount_l
                 w_df = df_i[['fund_id','volume']].set_index('fund_id').T
                 weighted_s = (index_df_i * w_df.values).sum(axis=1)
+                if weighted_s.empty:
+                    continue
                 ws = weighted_s.iloc[:-1]
                 ws = ws / ws[0] * last_value
                 last_value = ws[-1] 
                 index_res.append(ws)
             
             asset_weighted_index = pd.DataFrame(pd.concat(index_res)).rename(columns={0:index_id+' fund weighted sum'})
-            asset_weighted_index = index_price[[index_id]].join(asset_weighted_index).fillna(method='ffill').dropna()
+            asset_weighted_index = index_price[[index_id]].join(asset_weighted_index).dropna()
             asset_weighted_index = asset_weighted_index / asset_weighted_index.iloc[0]
             asset_weighted_index.plot.line(figsize=(15,12))
             last_value = round(asset_weighted_index[index_id+' fund weighted sum'].values[-1],4)
