@@ -70,8 +70,12 @@ class Calculator:
                 recent_y5_ret = sr[-1] / sr[0] - 1
             mdd_part =  sr[:] / sr[:].rolling(window=sr.shape[0], min_periods=1).max()
             mdd = 1 - mdd_part.min()
-            mdd_date2 = mdd_part.idxmin()
-            mdd_date1 = sr[:mdd_date2].idxmax()
+            if np.isnan(mdd):
+                mdd_date2 = None
+                mdd_date1 = None
+            else:
+                mdd_date2 = mdd_part.idxmin()
+                mdd_date1 = sr[:mdd_date2].idxmax()
             ret_over_mdd = annualized_ret / mdd if mdd != 0 else None
             last_mv_diff = sr[-1] - sr[-2]
             last_increase_rate = (sr[-1] - sr[-2])/ sr[-2]
@@ -109,6 +113,81 @@ class Calculator:
             last_increase_rate=last_increase_rate,
         )
 
+    @staticmethod
+    def get_manager_result(dates: pandas.core.series.Series,
+                          values: pandas.core.series.Series):
+        assert len(dates) == len(values), 'date and value has different numbers'
+        
+        if len(dates) > 1:
+            sr = pandas.Series(values, index=dates).sort_index()
+            risk_fee_rate = Calculator.get_risk_free_rate()
+            start_date = sr.index[0] 
+            end_date = sr.index[-1]
+            trade_year = sr.shape[0] / Calculator.TRADING_DAYS_PER_YEAR
+            last_unit_nav = sr[-1] / sr[0]
+            annualized_ret = np.exp(np.log(last_unit_nav) / trade_year) - 1
+            annualized_vol = (sr / sr.shift(1)).std(ddof=1) * np.sqrt(Calculator.TRADING_DAYS_PER_YEAR)
+            sharpe = (annualized_ret - risk_fee_rate) / annualized_vol
+            mdd_part =  sr[:] / sr[:].rolling(window=sr.shape[0], min_periods=1).max()
+            mdd = 1 - mdd_part.min()
+        # 如果只输入一天，返回空
+        else:
+            start_date = dates[0] if len(dates) > 0 else None
+            end_date = dates[0] if len(dates) > 0 else None
+            trade_year = 0
+            last_unit_nav = 1
+            annualized_ret = 0
+            annualized_vol = 0
+            sharpe = 0 
+            mdd = 0
+
+        return {
+            'start_date': start_date,
+            'end_date': end_date,
+            'trade_year' : trade_year,
+            'annualized_ret' : annualized_ret,
+            'annualized_vol' : annualized_vol,
+            'sharpe' : sharpe,
+            'mdd' : mdd,
+        }
+        
+    @staticmethod
+    def get_manager_stat_result(dates: pandas.core.series.Series,
+                                  values: pandas.core.series.Series,
+                                  benchmark_values: pandas.core.series.Series):
+        
+        assert len(dates) == len(values), 'date and port_values has different numbers'
+        assert len(dates) == len(benchmark_values), 'date and bench_values has different numbers'
+        res = Calculator.get_manager_result(dates, values)
+        sr_values  = pandas.Series(values, index=dates).sort_index()  
+        sr_values = sr_values / sr_values[0]
+        sr_benchmark_values = pandas.Series(benchmark_values, index=dates).sort_index()  
+        sr_benchmark_values = sr_benchmark_values / sr_benchmark_values[0]
+        sr_values_ret = sr_values / sr_values.shift(1)
+        sr_benchmark_ret = sr_benchmark_values / sr_benchmark_values.shift(1)
+        x = sr_benchmark_ret.dropna().values
+        y = sr_values_ret.dropna().values
+        x = sm.add_constant(x)
+        model = regression.linear_model.OLS(y,x).fit()
+        x = x[:,1]
+        alpha = model.params[0]
+        beta = model.params[1]
+        track_err = (sr_values_ret - sr_benchmark_ret).std(ddof=1) * np.sqrt(Calculator.TRADING_DAYS_PER_YEAR)
+        
+        return {
+                'start_date': res['start_date'],
+                'end_date': res['end_date'],
+                'trade_year':res['trade_year'],
+                'annualized_ret':res['annualized_ret'],
+                'annualized_vol':res['annualized_vol'],
+                'sharpe':res['sharpe'],
+                'mdd':res['mdd'],
+                'alpha':alpha,
+                'beta':beta,
+                'track_err':track_err,
+        }
+
+
     @staticmethod
     def get_benchmark_stat_result(dates: pandas.core.series.Series,
                                   values: pandas.core.series.Series,
