@@ -1,12 +1,16 @@
+
 import os
 import json
 import platform
+from typing import Dict
+
 from .singleton import Singleton
 
 DEFAULT_CONFIG_PATH = '/shared/surfing/etc/config.json'
 DEFAULT_LOG_DIR = '/shared/surfing/log/'
 DEFAULT_TMP_DIR = '/shared/surfing/tmp/'
 
+
 class SysSettings(object):
 
     def __init__(self, sys_json):
@@ -65,6 +69,33 @@ class CassandraSettings(object):
             self.hosts, self.port, self.username, self.password,
         )
 
+
+class AWSSettings:
+    """
+    Parse aws settings in config file
+    """
+
+    _DEFAULT_JSON: Dict[str, str] = {
+        'region_name': 'cn-northwest-1',
+        'aws_access_key_id': '',
+        'aws_secret_access_key': '',
+        'etl_tool_bucket_name': '',
+    }
+
+    def __init__(self, aws_json):
+        self.region_name: str = aws_json.get('region_name')
+        self.aws_access_key_id: str = aws_json.get('aws_access_key_id')
+        self.aws_secret_access_key: str = aws_json.get('aws_secret_access_key')
+        self.etl_tool_bucket_name: str = aws_json.get('etl_tool_bucket_name')
+
+    @classmethod
+    def get_default_config(cls):
+        return AWSSettings(cls._DEFAULT_JSON)
+
+    def __str__(self):
+        return f'region_name: {self.region_name}, aws_access_key_id: {self.aws_access_key_id}, etl_tool_bucket_name: {self.etl_tool_bucket_name}'
+
+
 class SurfingConfigurator(metaclass=Singleton):
 
     def __init__(self, config_path=DEFAULT_CONFIG_PATH):
@@ -97,3 +128,7 @@ class SurfingConfigurator(metaclass=Singleton):
     def get_cassandra_setting(self):
         assert 'surfing_cassandra' in self.config, 'could not find surfing_cassandra section in config'
         return CassandraSettings(self.config['surfing_cassandra'])
+
+    def get_aws_settings(self):
+        assert 'surfing_aws' in self.config, 'could not find surfing_aws section in config'
+        return AWSSettings(self.config['surfing_aws'])
